@@ -15,7 +15,7 @@ use Rose::DB::Object::Constants qw(:all);
 use Rose::DB::Constants qw(IN_TRANSACTION);
 use Rose::DB::Object::Util qw(row_id lazy_column_values_loaded_key);
 
-our $VERSION = '0.72';
+our $VERSION = '0.721';
 
 our $Debug = 0;
 
@@ -1548,6 +1548,69 @@ To define your own L<Rose::DB::Object>-derived class, you must describe the tabl
 
 Metadata objects can be populated manually or automatically.  Both techniques are shown in the L<synopsis|/SYNOPSIS> above.  The automatic mode works by asking the database itself for the information.  There are some caveats to this approach.  See the L<auto-initialization|Rose::DB::Object::Metadata/"AUTO-INITIALIZATION"> section of the L<Rose::DB::Object::Metadata> documentation for more information.
 
+=head2 Inheritance
+
+Simple inheritance between L<Rose::DB::Object>-derived classes is supported.  The first time the L<metadata object|/meta> for a given class is accessed, it is created by making a one-time "deep copy" of the base class's metadata object.  This includes all columns, relationships, foreign keys, and other metadata from the base class.  From that point on, the subclass may add to or modify its metadata without affecting any other class.
+
+B<Tip:> When using perl 5.8.0 or later, the L<Scalar::Util::Clone> module is highly recommended.  If it's installed, it will be used to more efficiently clone base-class metadata objects.
+
+If the base class has already been L<initilized|Rose::DB::Object::Metadata/initialize>, the subclass must explicitly specify whether it wants to create a new set of column and relationship methods, or merely inherit the methods from the base class.  If the subclass contains any metadata modifications that affect method creation, then it must create a new set of methods to reflect those changes.  
+
+Finally, note that column types cannot be changed "in-place."  To change a column type, delete the old column and add a new one with the same name.
+
+Example:
+
+  package BaseClass;
+  use base 'Rose::DB::Object';
+
+  __PACKAGE__->meta->table('objects');
+
+  __PACKAGE__->meta->columns
+  (
+    id    => { type => 'int', primary_key => 1 },
+    start => { type => 'scalar' },
+  );
+
+  __PACKAGE__->meta->initialize;
+
+  ...
+
+  package SubClass;
+  use base 'BaseClass';
+
+  # Set a default value for this column.
+  __PACKAGE__->meta->column('id')->default(123);
+
+  # Change the "start" column into a datetime column.
+  __PACKAGE__->meta->delete_column('start');
+  __PACKAGE__->meta->add_column(start => { type => 'datetime' });
+
+  # Initialize, replacing any inherited methods with newly created ones
+  __PACKAGE__->meta->initialize(replace_existing => 1);
+
+  ...
+
+  $b = BaseClass->new;
+
+  $id = $b->id; # undef
+
+  $b->start('1/2/2003');
+  print $b->start; # '1/2/2003' (plain string)
+
+
+  $s = SubClass->new;
+
+  $id = $s->id; # 123
+
+  $b->start('1/2/2003'); # Value is converted to a DateTime object
+  print $b->start->strftime('%B'); # 'January'
+
+To preserve all inherited methods in a subclass, do this instead:
+
+  package SubClass;
+  use base 'BaseClass';
+  __PACKAGE__->meta->initialize(preserve_existing => 1);
+
 =head2 Error Handling
 
 Error handling for L<Rose::DB::Object>-derived objects is controlled by the L<error_mode|Rose::DB::Object::Metadata/error_mode> method of the L<Rose::DB::Object::Metadata> object associated with the class (accessible via the L<meta|/meta> method).  The default setting is "fatal", which means that L<Rose::DB::Object> methods will L<croak|Carp/croak> if they encounter an error.
