@@ -2,12 +2,13 @@ package Rose::DB::Object::Metadata::Object;
 
 use strict;
 
+use Clone::PP();
 use Scalar::Util();
 
 use Rose::Object;
 our @ISA = qw(Rose::Object);
 
-our $VERSION = '0.01';
+our $VERSION = '0.721';
 
 sub parent
 {
@@ -16,4 +17,14 @@ sub parent
   return $self->{'parent'};
 }
 
+sub clone
+{
+  my($self) = shift;
+  
+  my $clone = Clone::PP::clone($self);
+  Scalar::Util::weaken($clone->{'parent'});
+
+  return $clone;
+}
+
 1;
